/* downloader.c generated by valac 0.26.0.19-b2255, the Vala compiler
 * generated from downloader.vala, do not modify */

/* This file is part of GNOME Boxes. License: LGPLv2+*/

#include <glib.h>
#include <glib-object.h>
#include <stdlib.h>
#include <string.h>
#include <gio/gio.h>
#include <libcommon.h>
#include <libsoup/soup.h>
#include <osinfo/osinfo.h>
#include <float.h>
#include <math.h>
#include <gtk/gtk.h>
#include <gdk-pixbuf/gdk-pixbuf.h>
#include <gobject/gvaluecollector.h>


#define BOXES_TYPE_DOWNLOAD (boxes_download_get_type ())
#define BOXES_DOWNLOAD(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DOWNLOAD, BoxesDownload))
#define BOXES_DOWNLOAD_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DOWNLOAD, BoxesDownloadClass))
#define BOXES_IS_DOWNLOAD(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DOWNLOAD))
#define BOXES_IS_DOWNLOAD_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DOWNLOAD))
#define BOXES_DOWNLOAD_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DOWNLOAD, BoxesDownloadClass))

typedef struct _BoxesDownload BoxesDownload;
typedef struct _BoxesDownloadClass BoxesDownloadClass;
typedef struct _BoxesDownloadPrivate BoxesDownloadPrivate;
#define _g_free0(var) (var = (g_free (var), NULL))
#define _g_object_unref0(var) ((var == NULL) ? NULL : (var = (g_object_unref (var), NULL)))
typedef struct _BoxesParamSpecDownload BoxesParamSpecDownload;

#define BOXES_TYPE_DOWNLOADER (boxes_downloader_get_type ())
#define BOXES_DOWNLOADER(obj) (G_TYPE_CHECK_INSTANCE_CAST ((obj), BOXES_TYPE_DOWNLOADER, BoxesDownloader))
#define BOXES_DOWNLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_CAST ((klass), BOXES_TYPE_DOWNLOADER, BoxesDownloaderClass))
#define BOXES_IS_DOWNLOADER(obj) (G_TYPE_CHECK_INSTANCE_TYPE ((obj), BOXES_TYPE_DOWNLOADER))
#define BOXES_IS_DOWNLOADER_CLASS(klass) (G_TYPE_CHECK_CLASS_TYPE ((klass), BOXES_TYPE_DOWNLOADER))
#define BOXES_DOWNLOADER_GET_CLASS(obj) (G_TYPE_INSTANCE_GET_CLASS ((obj), BOXES_TYPE_DOWNLOADER, BoxesDownloaderClass))

typedef struct _BoxesDownloader BoxesDownloader;
typedef struct _BoxesDownloaderClass BoxesDownloaderClass;
typedef struct _BoxesDownloaderPrivate BoxesDownloaderPrivate;
#define _g_hash_table_unref0(var) ((var == NULL) ? NULL : (var = (g_hash_table_unref (var), NULL)))
#define _boxes_download_unref0(var) ((var == NULL) ? NULL : (var = (boxes_download_unref (var), NULL)))
#define _g_error_free0(var) ((var == NULL) ? NULL : (var = (g_error_free (var), NULL)))
typedef struct _BoxesDownloaderDownloadData BoxesDownloaderDownloadData;
typedef struct _Block90Data Block90Data;
typedef struct _BoxesDownloaderDownloadFromHttpData BoxesDownloaderDownloadFromHttpData;
typedef struct _BoxesDownloaderFetchOsLogoData BoxesDownloaderFetchOsLogoData;
typedef struct _BoxesDownloaderFetchMediaData BoxesDownloaderFetchMediaData;
typedef struct _Block91Data Block91Data;
typedef struct _BoxesDownloaderAwaitDownloadData BoxesDownloaderAwaitDownloadData;

struct _BoxesDownload {
	GTypeInstance parent_instance;
	volatile int ref_count;
	BoxesDownloadPrivate * priv;
	gchar* uri;
	GFile* cached_file;
	BoxesActivityProgress* progress;
};

struct _BoxesDownloadClass {
	GTypeClass parent_class;
	void (*finalize) (BoxesDownload *self);
};

struct _BoxesParamSpecDownload {
	GParamSpec parent_instance;
};

struct _BoxesDownloader {
	GObject parent_instance;
	BoxesDownloaderPrivate * priv;
};

struct _BoxesDownloaderClass {
	GObjectClass parent_class;
};

struct _BoxesDownloaderPrivate {
	SoupSession* session;
	GHashTable* downloads;
};

struct _BoxesDownloaderDownloadData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesDownloader* self;
	GFile* remote_file;
	gchar** cached_paths;
	gint cached_paths_length1;
	BoxesActivityProgress* progress;
	GCancellable* cancellable;
	GFile* result;
	gchar* uri;
	GFile* _tmp0_;
	gchar* _tmp1_;
	BoxesDownload* download;
	GHashTable* _tmp2_;
	const gchar* _tmp3_;
	gconstpointer _tmp4_;
	BoxesDownload* _tmp5_;
	gchar* cached_path;
	gchar** _tmp6_;
	gint _tmp6__length1;
	const gchar* _tmp7_;
	gchar* _tmp8_;
	BoxesDownload* _tmp9_;
	GFile* _tmp10_;
	BoxesDownload* _tmp11_;
	const gchar* _tmp12_;
	BoxesActivityProgress* _tmp13_;
	GFile* _tmp14_;
	GFile* _tmp15_;
	GFile* cached_file;
	gchar** _tmp16_;
	gint _tmp16__length1;
	gchar** path_collection;
	gint path_collection_length1;
	gint _path_collection_size_;
	gint path_it;
	gchar* _tmp17_;
	gchar* path;
	const gchar* _tmp18_;
	GFile* _tmp19_;
	GFile* _tmp20_;
	gboolean _tmp21_;
	const gchar* _tmp22_;
	const gchar* _tmp23_;
	const gchar* _tmp24_;
	GFile* _tmp25_;
	const gchar* _tmp26_;
	const gchar* _tmp27_;
	GFile* _tmp28_;
	BoxesActivityProgress* _tmp29_;
	BoxesDownload* _tmp30_;
	GHashTable* _tmp31_;
	const gchar* _tmp32_;
	gchar* _tmp33_;
	BoxesDownload* _tmp34_;
	BoxesDownload* _tmp35_;
	gboolean _tmp36_;
	GFile* _tmp37_;
	gboolean _tmp38_;
	GFile* _tmp39_;
	gboolean _tmp40_;
	BoxesDownload* _tmp41_;
	GCancellable* _tmp42_;
	GFile* _tmp43_;
	GFile* _tmp44_;
	BoxesActivityProgress* _tmp45_;
	GCancellable* _tmp46_;
	GError* _error_;
	BoxesDownload* _tmp47_;
	GError* _tmp48_;
	GError* _tmp49_;
	GError* _tmp50_;
	GHashTable* _tmp51_;
	const gchar* _tmp52_;
	const gchar* _tmp53_;
	const gchar* _tmp54_;
	BoxesDownload* _tmp55_;
	GError * _inner_error_;
};

struct _Block90Data {
	int _ref_count_;
	BoxesDownloader* self;
	SoupMessage* msg;
	GError* err;
	gint64 total_num_bytes;
	GFileOutputStream* cached_file_stream;
	gint64 current_num_bytes;
	BoxesDownload* download;
	gpointer _async_data_;
};

struct _BoxesDownloaderDownloadFromHttpData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesDownloader* self;
	BoxesDownload* download;
	GCancellable* cancellable;
	Block90Data* _data90_;
	BoxesDownload* _tmp0_;
	BoxesDownload* _tmp1_;
	const gchar* _tmp2_;
	SoupMessage* _tmp3_;
	SoupMessage* _tmp4_;
	SoupMessageBody* _tmp5_;
	SoupAddress* address;
	SoupMessage* _tmp6_;
	SoupAddress* _tmp7_;
	SoupAddress* _tmp8_;
	GNetworkAddress* connectable;
	SoupAddress* _tmp9_;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	SoupAddress* _tmp12_;
	gint _tmp13_;
	gint _tmp14_;
	GNetworkAddress* _tmp15_;
	GNetworkMonitor* network_monitor;
	GNetworkMonitor* _tmp16_;
	GNetworkMonitor* _tmp17_;
	gboolean _tmp18_;
	GNetworkMonitor* _tmp19_;
	GNetworkAddress* _tmp20_;
	gboolean _tmp21_;
	SoupAddress* _tmp22_;
	const gchar* _tmp23_;
	const gchar* _tmp24_;
	SoupAddress* _tmp25_;
	gint _tmp26_;
	gint _tmp27_;
	GError* _tmp28_;
	gulong cancelled_id;
	GCancellable* _tmp29_;
	GCancellable* _tmp30_;
	gulong _tmp31_;
	SoupMessage* _tmp32_;
	BoxesDownload* _tmp33_;
	GFile* _tmp34_;
	GFileOutputStream* _tmp35_;
	SoupMessage* _tmp36_;
	SoupSession* _tmp37_;
	SoupMessage* _tmp38_;
	SoupMessage* _tmp39_;
	gulong _tmp40_;
	GCancellable* _tmp41_;
	gulong _tmp42_;
	SoupMessage* _tmp43_;
	guint _tmp44_;
	guint _tmp45_;
	BoxesDownload* _tmp46_;
	GFile* _tmp47_;
	GError* _tmp48_;
	GQuark _tmp49_;
	SoupMessage* _tmp50_;
	guint _tmp51_;
	guint _tmp52_;
	SoupMessage* _tmp53_;
	gchar* _tmp54_;
	gchar* _tmp55_;
	gchar* _tmp56_;
	GError* _tmp57_;
	GError* _tmp58_;
	GError* _tmp59_;
	GError * _inner_error_;
};

struct _BoxesDownloaderFetchOsLogoData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	GtkImage* image;
	OsinfoOs* os;
	gint size;
	gchar* logo_url;
	OsinfoOs* _tmp0_;
	gchar* _tmp1_;
	const gchar* _tmp2_;
	OsinfoOs* _tmp3_;
	const gchar* _tmp4_;
	const gchar* _tmp5_;
	const gchar* _tmp6_;
	GFile* remote_file;
	const gchar* _tmp7_;
	GFile* _tmp8_;
	gchar* system_cached_path;
	GFile* _tmp9_;
	gchar* _tmp10_;
	gchar* _tmp11_;
	gchar* _tmp12_;
	gchar* _tmp13_;
	gchar* cached_path;
	GFile* _tmp14_;
	gchar* _tmp15_;
	gchar* _tmp16_;
	gchar* _tmp17_;
	gchar* _tmp18_;
	gchar** cached_paths;
	const gchar* _tmp19_;
	gchar* _tmp20_;
	gchar** _tmp21_;
	gint cached_paths_length1;
	gint _cached_paths_size_;
	const gchar* _tmp22_;
	gchar** _tmp23_;
	gint _tmp23__length1;
	const gchar* _tmp24_;
	gchar* _tmp25_;
	GFile* cached_file;
	BoxesDownloader* _tmp26_;
	BoxesDownloader* _tmp27_;
	GFile* _tmp28_;
	gchar** _tmp29_;
	gint _tmp29__length1;
	BoxesActivityProgress* _tmp30_;
	BoxesActivityProgress* _tmp31_;
	GFile* _tmp32_;
	GFile* _tmp33_;
	GdkPixbuf* pixbuf;
	GFile* _tmp34_;
	gchar* _tmp35_;
	gchar* _tmp36_;
	gint _tmp37_;
	gint _tmp38_;
	GdkPixbuf* _tmp39_;
	GdkPixbuf* _tmp40_;
	GtkImage* _tmp41_;
	GdkPixbuf* _tmp42_;
	GError* _error_;
	const gchar* _tmp43_;
	GError* _tmp44_;
	const gchar* _tmp45_;
	GError * _inner_error_;
};

struct _BoxesDownloaderFetchMediaData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	gchar* uri;
	BoxesActivityProgress* progress;
	GCancellable* cancellable;
	gchar* result;
	GFile* file;
	const gchar* _tmp0_;
	GFile* _tmp1_;
	gchar* basename;
	GFile* _tmp2_;
	gchar* _tmp3_;
	gboolean _tmp4_;
	gboolean _tmp5_;
	const gchar* _tmp6_;
	const gchar* _tmp7_;
	const gchar* _tmp8_;
	BoxesDownloader* downloader;
	BoxesDownloader* _tmp9_;
	gchar* cache;
	const gchar* _tmp10_;
	const gchar* _tmp11_;
	gchar* _tmp12_;
	BoxesActivityProgress* _tmp13_;
	const gchar* _tmp14_;
	GFile* _tmp15_;
	gchar* _tmp16_;
	gchar** _tmp17_;
	gchar** _tmp18_;
	gint _tmp18__length1;
	BoxesActivityProgress* _tmp19_;
	GCancellable* _tmp20_;
	GFile* _tmp21_;
	GFile* _tmp22_;
	BoxesActivityProgress* _tmp23_;
	GError * _inner_error_;
};

struct _Block91Data {
	int _ref_count_;
	BoxesDownloader* self;
	GFile* downloaded_file;
	GError* download_error;
	GSourceFunc callback;
	gpointer callback_target;
	GDestroyNotify callback_target_destroy_notify;
	BoxesDownload* download;
	gpointer _async_data_;
};

struct _BoxesDownloaderAwaitDownloadData {
	int _state_;
	GObject* _source_object_;
	GAsyncResult* _res_;
	GSimpleAsyncResult* _async_result;
	BoxesDownloader* self;
	BoxesDownload* download;
	gchar* cached_path;
	BoxesActivityProgress* progress;
	GFile* result;
	Block91Data* _data91_;
	BoxesDownload* _tmp0_;
	BoxesDownload* _tmp1_;
	BoxesActivityProgress* _tmp2_;
	BoxesActivityProgress* _tmp3_;
	gulong downloaded_id;
	gulong _tmp4_;
	gulong downloaded_failed_id;
	gulong _tmp5_;
	BoxesDownload* _tmp6_;
	const gchar* _tmp7_;
	BoxesDownload* _tmp8_;
	const gchar* _tmp9_;
	GError* _tmp10_;
	GFile* cached_file;
	gchar* _tmp11_;
	gchar* _tmp12_;
	const gchar* _tmp13_;
	gboolean _tmp14_;
	const gchar* _tmp15_;
	GFile* _tmp16_;
	GFile* _tmp17_;
	GFile* _tmp18_;
	GError * _inner_error_;
};


static gpointer boxes_download_parent_class = NULL;
static gpointer boxes_downloader_parent_class = NULL;
static BoxesDownloader* boxes_downloader_downloader;
static BoxesDownloader* boxes_downloader_downloader = NULL;

gpointer boxes_download_ref (gpointer instance);
void boxes_download_unref (gpointer instance);
GParamSpec* boxes_param_spec_download (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags);
void boxes_value_set_download (GValue* value, gpointer v_object);
void boxes_value_take_download (GValue* value, gpointer v_object);
gpointer boxes_value_get_download (const GValue* value);
GType boxes_download_get_type (void) G_GNUC_CONST;
enum  {
	BOXES_DOWNLOAD_DUMMY_PROPERTY
};
BoxesDownload* boxes_download_new (const gchar* uri, GFile* cached_file, BoxesActivityProgress* progress);
BoxesDownload* boxes_download_construct (GType object_type, const gchar* uri, GFile* cached_file, BoxesActivityProgress* progress);
static void boxes_download_finalize (BoxesDownload* obj);
GType boxes_downloader_get_type (void) G_GNUC_CONST;
#define BOXES_DOWNLOADER_GET_PRIVATE(o) (G_TYPE_INSTANCE_GET_PRIVATE ((o), BOXES_TYPE_DOWNLOADER, BoxesDownloaderPrivate))
enum  {
	BOXES_DOWNLOADER_DUMMY_PROPERTY
};
BoxesDownloader* boxes_downloader_get_instance (void);
static BoxesDownloader* boxes_downloader_new (void);
static BoxesDownloader* boxes_downloader_construct (GType object_type);
static gchar* boxes_downloader_fetch_os_logo_url (OsinfoOs* os);
static void _g_free0_ (gpointer var);
static void _boxes_download_unref0_ (gpointer var);
static void boxes_downloader_download_data_free (gpointer _data);
void boxes_downloader_download (BoxesDownloader* self, GFile* remote_file, gchar** cached_paths, int cached_paths_length1, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
GFile* boxes_downloader_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
static gboolean boxes_downloader_download_co (BoxesDownloaderDownloadData* _data_);
static void boxes_downloader_await_download (BoxesDownloader* self, BoxesDownload* download, const gchar* cached_path, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_);
static GFile* boxes_downloader_await_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
static void boxes_downloader_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_downloader_download_from_http (BoxesDownloader* self, BoxesDownload* download, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
static void boxes_downloader_download_from_http_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error);
void boxes_copy_file (GFile* src_file, GFile* dest_file, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_copy_file_finish (GAsyncResult* _res_, GError** error);
static void boxes_downloader_download_from_http_data_free (gpointer _data);
static gboolean boxes_downloader_download_from_http_co (BoxesDownloaderDownloadFromHttpData* _data_);
static Block90Data* block90_data_ref (Block90Data* _data90_);
static void block90_data_unref (void * _userdata_);
static void boxes_downloader_download_from_http_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void ___lambda43_ (Block90Data* _data90_);
static void ____lambda43__gfunc (gconstpointer data, gpointer self);
static void __lambda44_ (Block90Data* _data90_);
static void ___lambda44__soup_message_got_headers (SoupMessage* _sender, gpointer self);
static void __lambda45_ (Block90Data* _data90_, SoupMessage* msg, SoupBuffer* chunk);
static void ___lambda45__soup_message_got_chunk (SoupMessage* _sender, SoupBuffer* chunk, gpointer self);
static void __lambda46_ (Block90Data* _data90_, SoupSession* session, SoupMessage* msg);
static void ___lambda46__soup_session_callback (SoupSession* session, SoupMessage* msg, gpointer self);
static void boxes_downloader_fetch_os_logo_data_free (gpointer _data);
void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_);
void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_);
static gboolean boxes_downloader_fetch_os_logo_co (BoxesDownloaderFetchOsLogoData* _data_);
static void _vala_array_add22 (gchar*** array, int* length, int* size, gchar* value);
static void boxes_downloader_fetch_os_logo_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_downloader_fetch_media_data_free (gpointer _data);
void boxes_downloader_fetch_media (const gchar* uri, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_);
gchar* boxes_downloader_fetch_media_finish (GAsyncResult* _res_, GError** error);
static gboolean boxes_downloader_fetch_media_co (BoxesDownloaderFetchMediaData* _data_);
static void boxes_downloader_fetch_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void boxes_downloader_await_download_data_free (gpointer _data);
static gboolean boxes_downloader_await_download_co (BoxesDownloaderAwaitDownloadData* _data_);
static Block91Data* block91_data_ref (Block91Data* _data91_);
static void block91_data_unref (void * _userdata_);
static gboolean _boxes_downloader_await_download_co_gsource_func (gpointer self);
static void __lambda41_ (Block91Data* _data91_, BoxesDownloader* downloader, BoxesDownload* downloaded);
static void ___lambda41__boxes_downloader_downloaded (BoxesDownloader* _sender, BoxesDownload* download, gpointer self);
static void __lambda42_ (Block91Data* _data91_, BoxesDownloader* downloader, BoxesDownload* failed_download, GError* _error_);
static void ___lambda42__boxes_downloader_download_failed (BoxesDownloader* _sender, BoxesDownload* download, GError* _error_, gpointer self);
static void boxes_downloader_await_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_);
static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD_POINTER (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data);
static void boxes_downloader_finalize (GObject* obj);
static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func);
static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func);


static gpointer _g_object_ref0 (gpointer self) {
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return self ? g_object_ref (self) : NULL;
#line 503 "downloader.c"
}


BoxesDownload* boxes_download_construct (GType object_type, const gchar* uri, GFile* cached_file, BoxesActivityProgress* progress) {
	BoxesDownload* self = NULL;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	GFile* _tmp3_ = NULL;
	BoxesActivityProgress* _tmp4_ = NULL;
	BoxesActivityProgress* _tmp5_ = NULL;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (uri != NULL, NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (cached_file != NULL, NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (progress != NULL, NULL);
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = (BoxesDownload*) g_type_create_instance (object_type);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = uri;
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (self->uri);
#line 9 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->uri = _tmp1_;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = cached_file;
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->cached_file);
#line 10 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->cached_file = _tmp3_;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = progress;
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->progress);
#line 11 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->progress = _tmp5_;
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return self;
#line 549 "downloader.c"
}


BoxesDownload* boxes_download_new (const gchar* uri, GFile* cached_file, BoxesActivityProgress* progress) {
#line 8 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return boxes_download_construct (BOXES_TYPE_DOWNLOAD, uri, cached_file, progress);
#line 556 "downloader.c"
}


static void boxes_value_download_init (GValue* value) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	value->data[0].v_pointer = NULL;
#line 563 "downloader.c"
}


static void boxes_value_download_free_value (GValue* value) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (value->data[0].v_pointer) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_download_unref (value->data[0].v_pointer);
#line 572 "downloader.c"
	}
}


static void boxes_value_download_copy_value (const GValue* src_value, GValue* dest_value) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (src_value->data[0].v_pointer) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		dest_value->data[0].v_pointer = boxes_download_ref (src_value->data[0].v_pointer);
#line 582 "downloader.c"
	} else {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		dest_value->data[0].v_pointer = NULL;
#line 586 "downloader.c"
	}
}


static gpointer boxes_value_download_peek_pointer (const GValue* value) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return value->data[0].v_pointer;
#line 594 "downloader.c"
}


static gchar* boxes_value_download_collect_value (GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (collect_values[0].v_pointer) {
#line 601 "downloader.c"
		BoxesDownload* object;
		object = collect_values[0].v_pointer;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (object->parent_instance.g_class == NULL) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return g_strconcat ("invalid unclassed object pointer for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 608 "downloader.c"
		} else if (!g_value_type_compatible (G_TYPE_FROM_INSTANCE (object), G_VALUE_TYPE (value))) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return g_strconcat ("invalid object type `", g_type_name (G_TYPE_FROM_INSTANCE (object)), "' for value type `", G_VALUE_TYPE_NAME (value), "'", NULL);
#line 612 "downloader.c"
		}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = boxes_download_ref (object);
#line 616 "downloader.c"
	} else {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = NULL;
#line 620 "downloader.c"
	}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return NULL;
#line 624 "downloader.c"
}


static gchar* boxes_value_download_lcopy_value (const GValue* value, guint n_collect_values, GTypeCValue* collect_values, guint collect_flags) {
	BoxesDownload** object_p;
	object_p = collect_values[0].v_pointer;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (!object_p) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return g_strdup_printf ("value location for `%s' passed as NULL", G_VALUE_TYPE_NAME (value));
#line 635 "downloader.c"
	}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (!value->data[0].v_pointer) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		*object_p = NULL;
#line 641 "downloader.c"
	} else if (collect_flags & G_VALUE_NOCOPY_CONTENTS) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		*object_p = value->data[0].v_pointer;
#line 645 "downloader.c"
	} else {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		*object_p = boxes_download_ref (value->data[0].v_pointer);
#line 649 "downloader.c"
	}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return NULL;
#line 653 "downloader.c"
}


GParamSpec* boxes_param_spec_download (const gchar* name, const gchar* nick, const gchar* blurb, GType object_type, GParamFlags flags) {
	BoxesParamSpecDownload* spec;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (g_type_is_a (object_type, BOXES_TYPE_DOWNLOAD), NULL);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	spec = g_param_spec_internal (G_TYPE_PARAM_OBJECT, name, nick, blurb, flags);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	G_PARAM_SPEC (spec)->value_type = object_type;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return G_PARAM_SPEC (spec);
#line 667 "downloader.c"
}


gpointer boxes_value_get_download (const GValue* value) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_DOWNLOAD), NULL);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return value->data[0].v_pointer;
#line 676 "downloader.c"
}


void boxes_value_set_download (GValue* value, gpointer v_object) {
	BoxesDownload* old;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	old = value->data[0].v_pointer;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (v_object) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = v_object;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_download_ref (value->data[0].v_pointer);
#line 696 "downloader.c"
	} else {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = NULL;
#line 700 "downloader.c"
	}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (old) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_download_unref (old);
#line 706 "downloader.c"
	}
}


void boxes_value_take_download (GValue* value, gpointer v_object) {
	BoxesDownload* old;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (G_TYPE_CHECK_VALUE_TYPE (value, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	old = value->data[0].v_pointer;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (v_object) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_return_if_fail (G_TYPE_CHECK_INSTANCE_TYPE (v_object, BOXES_TYPE_DOWNLOAD));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_return_if_fail (g_value_type_compatible (G_TYPE_FROM_INSTANCE (v_object), G_VALUE_TYPE (value)));
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = v_object;
#line 725 "downloader.c"
	} else {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		value->data[0].v_pointer = NULL;
#line 729 "downloader.c"
	}
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (old) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_download_unref (old);
#line 735 "downloader.c"
	}
}


static void boxes_download_class_init (BoxesDownloadClass * klass) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_download_parent_class = g_type_class_peek_parent (klass);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	((BoxesDownloadClass *) klass)->finalize = boxes_download_finalize;
#line 745 "downloader.c"
}


static void boxes_download_instance_init (BoxesDownload * self) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->ref_count = 1;
#line 752 "downloader.c"
}


static void boxes_download_finalize (BoxesDownload* obj) {
	BoxesDownload * self;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DOWNLOAD, BoxesDownload);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_handlers_destroy (self);
#line 4 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (self->uri);
#line 5 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->cached_file);
#line 6 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->progress);
#line 768 "downloader.c"
}


GType boxes_download_get_type (void) {
	static volatile gsize boxes_download_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_download_type_id__volatile)) {
		static const GTypeValueTable g_define_type_value_table = { boxes_value_download_init, boxes_value_download_free_value, boxes_value_download_copy_value, boxes_value_download_peek_pointer, "p", boxes_value_download_collect_value, "p", boxes_value_download_lcopy_value };
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDownloadClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_download_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDownload), 0, (GInstanceInitFunc) boxes_download_instance_init, &g_define_type_value_table };
		static const GTypeFundamentalInfo g_define_type_fundamental_info = { (G_TYPE_FLAG_CLASSED | G_TYPE_FLAG_INSTANTIATABLE | G_TYPE_FLAG_DERIVABLE | G_TYPE_FLAG_DEEP_DERIVABLE) };
		GType boxes_download_type_id;
		boxes_download_type_id = g_type_register_fundamental (g_type_fundamental_next (), "BoxesDownload", &g_define_type_info, &g_define_type_fundamental_info, 0);
		g_once_init_leave (&boxes_download_type_id__volatile, boxes_download_type_id);
	}
	return boxes_download_type_id__volatile;
}


gpointer boxes_download_ref (gpointer instance) {
	BoxesDownload* self;
	self = instance;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_atomic_int_inc (&self->ref_count);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return instance;
#line 793 "downloader.c"
}


void boxes_download_unref (gpointer instance) {
	BoxesDownload* self;
	self = instance;
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_atomic_int_dec_and_test (&self->ref_count)) {
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		BOXES_DOWNLOAD_GET_CLASS (self)->finalize (self);
#line 3 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_type_free_instance ((GTypeInstance *) self);
#line 806 "downloader.c"
	}
}


BoxesDownloader* boxes_downloader_get_instance (void) {
	BoxesDownloader* result = NULL;
	BoxesDownloader* _tmp0_ = NULL;
	BoxesDownloader* _tmp2_ = NULL;
	BoxesDownloader* _tmp3_ = NULL;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = boxes_downloader_downloader;
#line 25 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_tmp0_ == NULL) {
#line 820 "downloader.c"
		BoxesDownloader* _tmp1_ = NULL;
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp1_ = boxes_downloader_new ();
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (boxes_downloader_downloader);
#line 26 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_downloader_downloader = _tmp1_;
#line 828 "downloader.c"
	}
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = boxes_downloader_downloader;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	result = _tmp3_;
#line 28 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return result;
#line 838 "downloader.c"
}


static gchar* boxes_downloader_fetch_os_logo_url (OsinfoOs* os) {
	gchar* result = NULL;
	OsinfoOs* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	const gchar* _tmp2_ = NULL;
	gchar* logo_url = NULL;
	OsinfoProductList* derived = NULL;
	OsinfoOs* _tmp7_ = NULL;
	OsinfoProductList* _tmp8_ = NULL;
#line 31 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (os != NULL, NULL);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = os;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp0_);
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _tmp1_;
#line 32 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_tmp2_ != NULL) {
#line 861 "downloader.c"
		OsinfoOs* _tmp3_ = NULL;
		const gchar* _tmp4_ = NULL;
		const gchar* _tmp5_ = NULL;
		gchar* _tmp6_ = NULL;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp3_ = os;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp4_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp3_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp5_ = _tmp4_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp6_ = g_strdup (_tmp5_);
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		result = _tmp6_;
#line 33 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return result;
#line 878 "downloader.c"
	}
#line 35 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	logo_url = NULL;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp7_ = os;
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp8_ = osinfo_product_get_related ((OsinfoProduct*) _tmp7_, OSINFO_PRODUCT_RELATIONSHIP_DERIVES_FROM);
#line 36 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	derived = _tmp8_;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	while (TRUE) {
#line 890 "downloader.c"
		gboolean _tmp9_ = FALSE;
		OsinfoProductList* _tmp10_ = NULL;
		gint _tmp11_ = 0;
		OsinfoOs* parent = NULL;
		OsinfoProductList* _tmp13_ = NULL;
		OsinfoEntity* _tmp14_ = NULL;
		OsinfoOs* _tmp15_ = NULL;
		OsinfoOs* _tmp16_ = NULL;
		const gchar* _tmp17_ = NULL;
		const gchar* _tmp18_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp10_ = derived;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp11_ = osinfo_list_get_length ((OsinfoList*) _tmp10_);
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_tmp11_ > 0) {
#line 907 "downloader.c"
			const gchar* _tmp12_ = NULL;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp12_ = logo_url;
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp9_ = _tmp12_ == NULL;
#line 913 "downloader.c"
		} else {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp9_ = FALSE;
#line 917 "downloader.c"
		}
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (!_tmp9_) {
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			break;
#line 923 "downloader.c"
		}
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp13_ = derived;
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp14_ = osinfo_list_get_nth ((OsinfoList*) _tmp13_, 0);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp15_ = _g_object_ref0 (G_TYPE_CHECK_INSTANCE_TYPE (_tmp14_, osinfo_os_get_type ()) ? ((OsinfoOs*) _tmp14_) : NULL);
#line 39 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		parent = _tmp15_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp16_ = parent;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp17_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp16_);
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp18_ = _tmp17_;
#line 41 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_tmp18_ != NULL) {
#line 941 "downloader.c"
			OsinfoOs* _tmp19_ = NULL;
			const gchar* _tmp20_ = NULL;
			const gchar* _tmp21_ = NULL;
			gchar* _tmp22_ = NULL;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp19_ = parent;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp20_ = osinfo_product_get_logo ((OsinfoProduct*) _tmp19_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp21_ = _tmp20_;
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp22_ = g_strdup (_tmp21_);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_free0 (logo_url);
#line 42 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			logo_url = _tmp22_;
#line 958 "downloader.c"
		} else {
			OsinfoOs* _tmp23_ = NULL;
			OsinfoProductList* _tmp24_ = NULL;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp23_ = parent;
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp24_ = osinfo_product_get_related ((OsinfoProduct*) _tmp23_, OSINFO_PRODUCT_RELATIONSHIP_DERIVES_FROM);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (derived);
#line 44 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			derived = _tmp24_;
#line 970 "downloader.c"
		}
#line 37 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (parent);
#line 974 "downloader.c"
	}
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	result = logo_url;
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (derived);
#line 47 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return result;
#line 982 "downloader.c"
}


static void _g_free0_ (gpointer var) {
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	var = (g_free (var), NULL);
#line 989 "downloader.c"
}


static void _boxes_download_unref0_ (gpointer var) {
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	(var == NULL) ? NULL : (var = (boxes_download_unref (var), NULL));
#line 996 "downloader.c"
}


static BoxesDownloader* boxes_downloader_construct (GType object_type) {
	BoxesDownloader * self = NULL;
	GHashFunc _tmp0_ = NULL;
	GEqualFunc _tmp1_ = NULL;
	GHashTable* _tmp2_ = NULL;
	SoupSession* _tmp3_ = NULL;
	SoupSession* _tmp4_ = NULL;
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = (BoxesDownloader*) g_object_new (object_type, NULL);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = g_str_hash;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = g_str_equal;
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = g_hash_table_new_full (_tmp0_, _tmp1_, _g_free0_, _boxes_download_unref0_);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_hash_table_unref0 (self->priv->downloads);
#line 51 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->priv->downloads = _tmp2_;
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = soup_session_new ();
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->priv->session);
#line 53 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->priv->session = _tmp3_;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = self->priv->session;
#line 54 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	soup_session_add_feature_by_type (_tmp4_, soup_proxy_resolver_default_get_type ());
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return self;
#line 1031 "downloader.c"
}


static BoxesDownloader* boxes_downloader_new (void) {
#line 50 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return boxes_downloader_construct (BOXES_TYPE_DOWNLOADER);
#line 1038 "downloader.c"
}


static void boxes_downloader_download_data_free (gpointer _data) {
	BoxesDownloaderDownloadData* _data_;
	_data_ = _data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->remote_file);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->result);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderDownloadData, _data_);
#line 1057 "downloader.c"
}


void boxes_downloader_download (BoxesDownloader* self, GFile* remote_file, gchar** cached_paths, int cached_paths_length1, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderDownloadData* _data_;
	BoxesDownloader* _tmp0_ = NULL;
	GFile* _tmp1_ = NULL;
	GFile* _tmp2_ = NULL;
	gchar** _tmp3_ = NULL;
	gint _tmp3__length1 = 0;
	BoxesActivityProgress* _tmp4_ = NULL;
	BoxesActivityProgress* _tmp5_ = NULL;
	GCancellable* _tmp6_ = NULL;
	GCancellable* _tmp7_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderDownloadData);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_downloader_download);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_downloader_download_data_free);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->self = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = remote_file;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _g_object_ref0 (_tmp1_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->remote_file);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->remote_file = _tmp2_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = cached_paths;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3__length1 = cached_paths_length1;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths = _tmp3_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths_length1 = _tmp3__length1;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = progress;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->progress = _tmp5_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp6_ = cancellable;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp7_ = _g_object_ref0 (_tmp6_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cancellable = _tmp7_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_co (_data_);
#line 1116 "downloader.c"
}


GFile* boxes_downloader_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error) {
	GFile* result;
	BoxesDownloaderDownloadData* _data_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return NULL;
#line 1127 "downloader.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	result = _data_->result;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->result = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return result;
#line 1137 "downloader.c"
}


/**
     * Downloads the given file.
     *
     * @param remote_file The remote file to download.
     * @param cached_paths Array of cache directories. The file will be saved in the directory the
     *                     first element points to.
     * @param progress The ActivityProgress object to report progress to.
     * @param cancellable The Cancellable object for cancellation.
     *
     * @return A file handle to the (now) local file.
     */
static gpointer _boxes_download_ref0 (gpointer self) {
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return self ? boxes_download_ref (self) : NULL;
#line 1155 "downloader.c"
}


static void boxes_downloader_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderDownloadData* _data_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_co (_data_);
#line 1169 "downloader.c"
}


static gpointer _g_error_copy0 (gpointer self) {
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return self ? g_error_copy (self) : NULL;
#line 1176 "downloader.c"
}


static gboolean boxes_downloader_download_co (BoxesDownloaderDownloadData* _data_) {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 0:
#line 1185 "downloader.c"
		goto _state_0;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 1:
#line 1189 "downloader.c"
		goto _state_1;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 2:
#line 1193 "downloader.c"
		goto _state_2;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 3:
#line 1197 "downloader.c"
		goto _state_3;
		default:
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 1202 "downloader.c"
	}
	_state_0:
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->remote_file;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = NULL;
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = g_file_get_uri (_data_->_tmp0_);
#line 72 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->uri = _data_->_tmp1_;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->self->priv->downloads;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = _data_->uri;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = g_hash_table_lookup (_data_->_tmp2_, _data_->_tmp3_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = NULL;
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = _boxes_download_ref0 ((BoxesDownload*) _data_->_tmp4_);
#line 73 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->download = _data_->_tmp5_;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6__length1 = 0;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->cached_paths;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6__length1 = _data_->cached_paths_length1;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = _data_->_tmp6_[0];
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = NULL;
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = g_strdup (_data_->_tmp7_);
#line 74 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_path = _data_->_tmp8_;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = NULL;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->download;
#line 76 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp9_ != NULL) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp11_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp11_ = _data_->download;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp12_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp12_ = _data_->cached_path;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp13_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp13_ = _data_->progress;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_state_ = 1;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_downloader_await_download (_data_->self, _data_->_tmp11_, _data_->_tmp12_, _data_->_tmp13_, boxes_downloader_download_ready, _data_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1275 "downloader.c"
		_state_1:
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp14_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp14_ = boxes_downloader_await_download_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = _data_->_tmp14_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_error_free (_data_->_inner_error_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_free0 (_data_->cached_path);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_boxes_download_unref0 (_data_->download);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_free0 (_data_->uri);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			if (_data_->_state_ == 0) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1299 "downloader.c"
			} else {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 1303 "downloader.c"
			}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_object_unref (_data_->_async_result);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 1309 "downloader.c"
		}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp15_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp15_ = _data_->_tmp10_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = NULL;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->result = _data_->_tmp15_;
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->_tmp10_);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cached_path);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data_->download);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->uri);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1331 "downloader.c"
		} else {
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1335 "downloader.c"
		}
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 78 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1341 "downloader.c"
	}
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16__length1 = 0;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = _data_->cached_paths;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16__length1 = _data_->cached_paths_length1;
#line 1351 "downloader.c"
	{
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->path_collection_length1 = 0;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_path_collection_size_ = 0;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->path_collection = _data_->_tmp16_;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->path_collection_length1 = _data_->_tmp16__length1;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		for (_data_->path_it = 0; _data_->path_it < _data_->_tmp16__length1; _data_->path_it = _data_->path_it + 1) {
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp17_ = NULL;
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp17_ = g_strdup (_data_->path_collection[_data_->path_it]);
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->path = _data_->_tmp17_;
#line 1369 "downloader.c"
			{
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp18_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp18_ = _data_->path;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp19_ = NULL;
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp19_ = g_file_new_for_path (_data_->_tmp18_);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_g_object_unref0 (_data_->cached_file);
#line 82 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->cached_file = _data_->_tmp19_;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp20_ = NULL;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp20_ = _data_->cached_file;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp21_ = FALSE;
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_data_->_tmp21_ = g_file_query_exists (_data_->_tmp20_, NULL);
#line 83 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				if (_data_->_tmp21_) {
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_data_->_tmp22_ = NULL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_data_->_tmp22_ = _data_->uri;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_data_->_tmp23_ = NULL;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_data_->_tmp23_ = _data_->path;
#line 84 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					g_debug ("downloader.vala:84: '%s' already available locally at '%s'. Not downlo" \
"ading.", _data_->_tmp22_, _data_->_tmp23_);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_data_->result = _data_->cached_file;
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_g_free0 (_data_->path);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_g_free0 (_data_->cached_path);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_boxes_download_unref0 (_data_->download);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					_g_free0 (_data_->uri);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					if (_data_->_state_ == 0) {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
						g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1417 "downloader.c"
					} else {
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
						g_simple_async_result_complete (_data_->_async_result);
#line 1421 "downloader.c"
					}
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					g_object_unref (_data_->_async_result);
#line 85 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
					return FALSE;
#line 1427 "downloader.c"
				}
#line 81 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				_g_free0 (_data_->path);
#line 1431 "downloader.c"
			}
		}
	}
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp24_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp24_ = _data_->cached_path;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp25_ = NULL;
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp25_ = g_file_new_for_path (_data_->_tmp24_);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cached_file);
#line 89 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_file = _data_->_tmp25_;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp26_ = NULL;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp26_ = _data_->uri;
#line 90 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:90: Downloading '%s'...", _data_->_tmp26_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp27_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp27_ = _data_->uri;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp28_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp28_ = _data_->cached_file;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp29_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp29_ = _data_->progress;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp30_ = NULL;
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp30_ = boxes_download_new (_data_->_tmp27_, _data_->_tmp28_, _data_->_tmp29_);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 91 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->download = _data_->_tmp30_;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp31_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp31_ = _data_->self->priv->downloads;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp32_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp32_ = _data_->uri;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp33_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp33_ = g_strdup (_data_->_tmp32_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp34_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp34_ = _data_->download;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp35_ = NULL;
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp35_ = _boxes_download_ref0 (_data_->_tmp34_);
#line 92 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_hash_table_insert (_data_->_tmp31_, _data_->_tmp33_, _data_->_tmp35_);
#line 1495 "downloader.c"
	{
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp37_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp37_ = _data_->remote_file;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp38_ = FALSE;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp38_ = g_file_has_uri_scheme (_data_->_tmp37_, "http");
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_tmp38_) {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp36_ = TRUE;
#line 1509 "downloader.c"
		} else {
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp39_ = NULL;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp39_ = _data_->remote_file;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp40_ = FALSE;
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp40_ = g_file_has_uri_scheme (_data_->_tmp39_, "https");
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp36_ = _data_->_tmp40_;
#line 1521 "downloader.c"
		}
#line 95 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_tmp36_) {
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp41_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp41_ = _data_->download;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp42_ = NULL;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp42_ = _data_->cancellable;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_state_ = 2;
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			boxes_downloader_download_from_http (_data_->self, _data_->_tmp41_, _data_->_tmp42_, boxes_downloader_download_ready, _data_);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 1539 "downloader.c"
			_state_2:
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			boxes_downloader_download_from_http_finish (_data_->self, _data_->_res_, &_data_->_inner_error_);
#line 96 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1545 "downloader.c"
				goto __catch126_g_error;
			}
		} else {
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp43_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp43_ = _data_->remote_file;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp44_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp44_ = _data_->cached_file;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp45_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp45_ = _data_->progress;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp46_ = NULL;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp46_ = _data_->cancellable;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_state_ = 3;
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			boxes_copy_file (_data_->_tmp43_, _data_->_tmp44_, _data_->_tmp45_, _data_->_tmp46_, boxes_downloader_download_ready, _data_);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 1571 "downloader.c"
			_state_3:
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			boxes_copy_file_finish (_data_->_res_, &_data_->_inner_error_);
#line 98 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 1577 "downloader.c"
				goto __catch126_g_error;
			}
		}
	}
	goto __finally126;
	__catch126_g_error:
	{
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp47_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp47_ = _data_->download;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp48_ = NULL;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp48_ = _data_->_error_;
#line 100 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_signal_emit_by_name (_data_->self, "download-failed", _data_->_tmp47_, _data_->_tmp48_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp49_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp49_ = _data_->_error_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp50_ = NULL;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp50_ = _g_error_copy0 (_data_->_tmp49_);
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp50_;
#line 102 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data_->_error_);
#line 1611 "downloader.c"
		goto __finally126;
	}
	__finally126:
	{
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp51_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp51_ = _data_->self->priv->downloads;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp52_ = NULL;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp52_ = _data_->uri;
#line 104 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_hash_table_remove (_data_->_tmp51_, _data_->_tmp52_);
#line 1626 "downloader.c"
	}
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cached_path);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data_->download);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->uri);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1646 "downloader.c"
		} else {
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 1650 "downloader.c"
		}
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 94 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 1656 "downloader.c"
	}
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp53_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp53_ = _data_->uri;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp54_ = NULL;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp54_ = _data_->cached_path;
#line 107 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:107: Downloaded '%s' and its now locally available at " \
"'%s'.", _data_->_tmp53_, _data_->_tmp54_);
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp55_ = NULL;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp55_ = _data_->download;
#line 108 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_emit_by_name (_data_->self, "downloaded", _data_->_tmp55_);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->result = _data_->cached_file;
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->uri);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1686 "downloader.c"
	} else {
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1690 "downloader.c"
	}
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 110 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cached_file);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->uri);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 1708 "downloader.c"
	} else {
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 1712 "downloader.c"
	}
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 68 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 1718 "downloader.c"
}


static void boxes_downloader_download_from_http_data_free (gpointer _data) {
	BoxesDownloaderDownloadFromHttpData* _data_;
	_data_ = _data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderDownloadFromHttpData, _data_);
#line 1731 "downloader.c"
}


static void boxes_downloader_download_from_http (BoxesDownloader* self, BoxesDownload* download, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderDownloadFromHttpData* _data_;
	BoxesDownloader* _tmp0_ = NULL;
	BoxesDownload* _tmp1_ = NULL;
	BoxesDownload* _tmp2_ = NULL;
	GCancellable* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderDownloadFromHttpData);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_downloader_download_from_http);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_downloader_download_from_http_data_free);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->self = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = download;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _boxes_download_ref0 (_tmp1_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->download = _tmp2_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = cancellable;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = _g_object_ref0 (_tmp3_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cancellable = _tmp4_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_from_http_co (_data_);
#line 1770 "downloader.c"
}


static void boxes_downloader_download_from_http_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error) {
	BoxesDownloaderDownloadFromHttpData* _data_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return;
#line 1780 "downloader.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 1784 "downloader.c"
}


static Block90Data* block90_data_ref (Block90Data* _data90_) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_atomic_int_inc (&_data90_->_ref_count_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return _data90_;
#line 1793 "downloader.c"
}


static void block90_data_unref (void * _userdata_) {
	Block90Data* _data90_;
	_data90_ = (Block90Data*) _userdata_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_atomic_int_dec_and_test (&_data90_->_ref_count_)) {
#line 1802 "downloader.c"
		BoxesDownloader* self;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		self = _data90_->self;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data90_->cached_file_stream);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data90_->err);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data90_->msg);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data90_->download);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (self);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_slice_free (Block90Data, _data90_);
#line 1818 "downloader.c"
	}
}


static void boxes_downloader_download_from_http_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderDownloadFromHttpData* _data_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_from_http_co (_data_);
#line 1833 "downloader.c"
}


static void ___lambda43_ (Block90Data* _data90_) {
	BoxesDownloader* self;
	GError* _tmp0_ = NULL;
	SoupSession* _tmp1_ = NULL;
	SoupMessage* _tmp2_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = _data90_->self;
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = g_error_new_literal (G_IO_ERROR, G_IO_ERROR_CANCELLED, "Cancelled by cancellable.");
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_error_free0 (_data90_->err);
#line 126 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data90_->err = _tmp0_;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = self->priv->session;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _data90_->msg;
#line 127 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	soup_session_cancel_message (_tmp1_, _tmp2_, (guint) SOUP_STATUS_CANCELLED);
#line 1856 "downloader.c"
}


static void ____lambda43__gfunc (gconstpointer data, gpointer self) {
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	___lambda43_ (self);
#line 1863 "downloader.c"
}


static void __lambda44_ (Block90Data* _data90_) {
	BoxesDownloader* self;
	SoupMessage* _tmp0_ = NULL;
	SoupMessageHeaders* _tmp1_ = NULL;
	gint64 _tmp2_ = 0LL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = _data90_->self;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = _data90_->msg;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = _tmp0_->response_headers;
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = soup_message_headers_get_content_length (_tmp1_);
#line 132 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data90_->total_num_bytes = _tmp2_;
#line 1882 "downloader.c"
}


static void ___lambda44__soup_message_got_headers (SoupMessage* _sender, gpointer self) {
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	__lambda44_ (self);
#line 1889 "downloader.c"
}


static void __lambda45_ (Block90Data* _data90_, SoupMessage* msg, SoupBuffer* chunk) {
	BoxesDownloader* self;
	gint64 _tmp0_ = 0LL;
	SoupBuffer* _tmp1_ = NULL;
	gsize _tmp2_ = 0UL;
	GError * _inner_error_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = _data90_->self;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (msg != NULL);
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (chunk != NULL);
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = _data90_->current_num_bytes;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = chunk;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _tmp1_->length;
#line 140 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data90_->current_num_bytes = _tmp0_ + _tmp2_;
#line 1913 "downloader.c"
	{
		GFileOutputStream* _tmp3_ = NULL;
		SoupBuffer* _tmp4_ = NULL;
		guint8* _tmp5_ = NULL;
		gint _tmp5__length1 = 0;
		gint64 _tmp6_ = 0LL;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp3_ = _data90_->cached_file_stream;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp4_ = chunk;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp5_ = _tmp4_->data;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp5__length1 = (gint) _tmp4_->length;
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_output_stream_write ((GOutputStream*) _tmp3_, _tmp5_, (gsize) _tmp5__length1, NULL, &_inner_error_);
#line 145 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 1932 "downloader.c"
			goto __catch127_g_error;
		}
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp6_ = _data90_->total_num_bytes;
#line 146 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_tmp6_ > ((gint64) 0)) {
#line 1939 "downloader.c"
			BoxesDownload* _tmp7_ = NULL;
			BoxesActivityProgress* _tmp8_ = NULL;
			gint64 _tmp9_ = 0LL;
			gint64 _tmp10_ = 0LL;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp7_ = _data90_->download;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp8_ = _tmp7_->progress;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp9_ = _data90_->current_num_bytes;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_tmp10_ = _data90_->total_num_bytes;
#line 148 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			boxes_activity_progress_set_progress (_tmp8_, ((gdouble) _tmp9_) / _tmp10_);
#line 1954 "downloader.c"
		}
	}
	goto __finally127;
	__catch127_g_error:
	{
		GError* e = NULL;
		GError* _tmp11_ = NULL;
		GError* _tmp12_ = NULL;
		SoupSession* _tmp13_ = NULL;
		SoupMessage* _tmp14_ = NULL;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		e = _inner_error_;
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_inner_error_ = NULL;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp11_ = e;
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp12_ = _g_error_copy0 (_tmp11_);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data90_->err);
#line 150 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data90_->err = _tmp12_;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp13_ = self->priv->session;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_tmp14_ = msg;
#line 151 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		soup_session_cancel_message (_tmp13_, _tmp14_, (guint) SOUP_STATUS_CANCELLED);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_error_free0 (e);
#line 1985 "downloader.c"
	}
	__finally127:
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_inner_error_ != NULL)) {
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _inner_error_->message, g_quark_to_string (_inner_error_->domain), _inner_error_->code);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_clear_error (&_inner_error_);
#line 141 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return;
#line 1996 "downloader.c"
	}
}


static void ___lambda45__soup_message_got_chunk (SoupMessage* _sender, SoupBuffer* chunk, gpointer self) {
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	__lambda45_ (self, _sender, chunk);
#line 2004 "downloader.c"
}


static void __lambda46_ (Block90Data* _data90_, SoupSession* session, SoupMessage* msg) {
	BoxesDownloader* self;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = _data90_->self;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (session != NULL);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (msg != NULL);
#line 156 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_download_from_http_co (_data90_->_async_data_);
#line 2018 "downloader.c"
}


static void ___lambda46__soup_session_callback (SoupSession* session, SoupMessage* msg, gpointer self) {
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	__lambda46_ (self, session, msg);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	block90_data_unref (self);
#line 2027 "downloader.c"
}


static gboolean boxes_downloader_download_from_http_co (BoxesDownloaderDownloadFromHttpData* _data_) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 0:
#line 2036 "downloader.c"
		goto _state_0;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 1:
#line 2040 "downloader.c"
		goto _state_1;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 2:
#line 2044 "downloader.c"
		goto _state_2;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 3:
#line 2048 "downloader.c"
		goto _state_3;
		default:
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 2053 "downloader.c"
	}
	_state_0:
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data90_ = g_slice_new0 (Block90Data);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data90_->_ref_count_ = 1;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data90_->self = g_object_ref (_data_->self);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->download;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->_data90_->download);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data90_->download = _data_->_tmp0_;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data90_->_async_data_ = _data_;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = _data_->_data90_->download;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->_tmp1_->uri;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = NULL;
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = soup_message_new ("GET", _data_->_tmp2_);
#line 114 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data90_->msg = _data_->_tmp3_;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = _data_->_data90_->msg;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = NULL;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = _data_->_tmp4_->response_body;
#line 115 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	soup_message_body_set_accumulate (_data_->_tmp5_, FALSE);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->_data90_->msg;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = soup_message_get_address (_data_->_tmp6_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = NULL;
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = _g_object_ref0 (_data_->_tmp7_);
#line 116 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->address = _data_->_tmp8_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->address;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = soup_address_get_name (_data_->_tmp9_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = _data_->_tmp10_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = _data_->address;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = 0;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = soup_address_get_port (_data_->_tmp12_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = 0;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = _data_->_tmp13_;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = NULL;
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = (GNetworkAddress*) g_network_address_new (_data_->_tmp11_, (guint16) _data_->_tmp14_);
#line 117 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->connectable = _data_->_tmp15_;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = NULL;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = g_network_monitor_get_default ();
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = NULL;
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = _g_object_ref0 (_data_->_tmp16_);
#line 118 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->network_monitor = _data_->_tmp17_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = _data_->network_monitor;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = _data_->connectable;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 1;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_network_monitor_can_reach_async (_data_->_tmp19_, (GSocketConnectable*) _data_->_tmp20_, NULL, boxes_downloader_download_from_http_ready, _data_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2164 "downloader.c"
	_state_1:
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = FALSE;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = g_network_monitor_can_reach_finish (_data_->_tmp19_, _data_->_res_, &_data_->_inner_error_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = _data_->_tmp21_;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		block90_data_unref (_data_->_data90_);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_data90_ = NULL;
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2192 "downloader.c"
		} else {
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2196 "downloader.c"
		}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2202 "downloader.c"
	}
#line 119 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (!_data_->_tmp18_) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp22_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp22_ = _data_->address;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23_ = soup_address_get_name (_data_->_tmp22_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp24_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp24_ = _data_->_tmp23_;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp25_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp25_ = _data_->address;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp26_ = 0;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp26_ = soup_address_get_port (_data_->_tmp25_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp27_ = 0;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp27_ = _data_->_tmp26_;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp28_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp28_ = g_error_new (BOXES_ERROR, BOXES_ERROR_INVALID, "Failed to reach host '%s' on port '%d'", _data_->_tmp24_, _data_->_tmp27_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp28_;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		block90_data_unref (_data_->_data90_);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_data90_ = NULL;
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2254 "downloader.c"
		} else {
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2258 "downloader.c"
		}
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 120 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2264 "downloader.c"
	}
#line 122 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data90_->err = NULL;
#line 123 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cancelled_id = (gulong) 0;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp29_ = NULL;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp29_ = _data_->cancellable;
#line 124 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp29_ != NULL) {
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp30_ = NULL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp30_ = _data_->cancellable;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp31_ = 0UL;
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp31_ = g_cancellable_connect (_data_->_tmp30_, (GCallback) ____lambda43__gfunc, block90_data_ref (_data_->_data90_), block90_data_unref);
#line 125 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->cancelled_id = _data_->_tmp31_;
#line 2286 "downloader.c"
	}
#line 130 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data90_->total_num_bytes = (gint64) 0;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp32_ = NULL;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp32_ = _data_->_data90_->msg;
#line 131 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_connect_data (_data_->_tmp32_, "got-headers", (GCallback) ___lambda44__soup_message_got_headers, block90_data_ref (_data_->_data90_), (GClosureNotify) block90_data_unref, 0);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp33_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp33_ = _data_->_data90_->download;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp34_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp34_ = _data_->_tmp33_->cached_file;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 2;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_file_create_async (_data_->_tmp34_, G_FILE_CREATE_NONE, G_PRIORITY_DEFAULT, NULL, boxes_downloader_download_from_http_ready, _data_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2310 "downloader.c"
	_state_2:
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp35_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp35_ = g_file_create_finish (_data_->_tmp34_, _data_->_res_, &_data_->_inner_error_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data90_->cached_file_stream = _data_->_tmp35_;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		block90_data_unref (_data_->_data90_);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_data90_ = NULL;
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2338 "downloader.c"
		} else {
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2342 "downloader.c"
		}
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 135 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2348 "downloader.c"
	}
#line 137 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data90_->current_num_bytes = (gint64) 0;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp36_ = NULL;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp36_ = _data_->_data90_->msg;
#line 139 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_connect_data (_data_->_tmp36_, "got-chunk", (GCallback) ___lambda45__soup_message_got_chunk, block90_data_ref (_data_->_data90_), (GClosureNotify) block90_data_unref, 0);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp37_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp37_ = _data_->self->priv->session;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp38_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp38_ = _data_->_data90_->msg;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp39_ = NULL;
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp39_ = _g_object_ref0 (_data_->_tmp38_);
#line 155 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	soup_session_queue_message (_data_->_tmp37_, _data_->_tmp39_, ___lambda46__soup_session_callback, block90_data_ref (_data_->_data90_));
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 3;
#line 159 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2376 "downloader.c"
	_state_3:
	;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp40_ = 0UL;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp40_ = _data_->cancelled_id;
#line 161 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp40_ != ((gulong) 0)) {
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp41_ = NULL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp41_ = _data_->cancellable;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp42_ = 0UL;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp42_ = _data_->cancelled_id;
#line 162 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_cancellable_disconnect (_data_->_tmp41_, _data_->_tmp42_);
#line 2395 "downloader.c"
	}
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp43_ = NULL;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp43_ = _data_->_data90_->msg;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp44_ = 0U;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_get (_data_->_tmp43_, "status-code", &_data_->_tmp44_, NULL);
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp45_ = 0U;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp45_ = _data_->_tmp44_;
#line 164 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp45_ != ((guint) SOUP_STATUS_OK)) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp46_ = NULL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp46_ = _data_->_data90_->download;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp47_ = NULL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp47_ = _data_->_tmp46_->cached_file;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_file_delete (_data_->_tmp47_, NULL, &_data_->_inner_error_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_error_free (_data_->_inner_error_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->network_monitor);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->connectable);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->address);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			block90_data_unref (_data_->_data90_);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_data90_ = NULL;
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			if (_data_->_state_ == 0) {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2441 "downloader.c"
			} else {
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 2445 "downloader.c"
			}
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_object_unref (_data_->_async_result);
#line 165 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 2451 "downloader.c"
		}
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp48_ = NULL;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp48_ = _data_->_data90_->err;
#line 166 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_tmp48_ == NULL) {
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp49_ = 0U;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp49_ = soup_http_error_quark ();
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp50_ = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp50_ = _data_->_data90_->msg;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp51_ = 0U;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_object_get (_data_->_tmp50_, "status-code", &_data_->_tmp51_, NULL);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp52_ = 0U;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp52_ = _data_->_tmp51_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp53_ = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp53_ = _data_->_data90_->msg;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp54_ = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_object_get (_data_->_tmp53_, "reason-phrase", &_data_->_tmp54_, NULL);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp55_ = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp55_ = _data_->_tmp54_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp56_ = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp56_ = _data_->_tmp55_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp57_ = NULL;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_tmp57_ = g_error_new (_data_->_tmp49_, (gint) _data_->_tmp52_, _data_->_tmp56_);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_error_free0 (_data_->_data90_->err);
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_data90_->err = _data_->_tmp57_;
#line 167 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_free0 (_data_->_tmp56_);
#line 2501 "downloader.c"
		}
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp58_ = NULL;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp58_ = _data_->_data90_->err;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp59_ = NULL;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp59_ = _g_error_copy0 (_data_->_tmp58_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp59_;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->network_monitor);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->connectable);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->address);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		block90_data_unref (_data_->_data90_);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_data90_ = NULL;
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2531 "downloader.c"
		} else {
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2535 "downloader.c"
		}
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 169 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2541 "downloader.c"
	}
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->network_monitor);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->connectable);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->address);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	block90_data_unref (_data_->_data90_);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data90_ = NULL;
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2557 "downloader.c"
	} else {
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 2561 "downloader.c"
	}
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 113 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 2567 "downloader.c"
}


static void boxes_downloader_fetch_os_logo_data_free (gpointer _data) {
	BoxesDownloaderFetchOsLogoData* _data_;
	_data_ = _data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->image);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->os);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderFetchOsLogoData, _data_);
#line 2580 "downloader.c"
}


void boxes_downloader_fetch_os_logo (GtkImage* image, OsinfoOs* os, gint size, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderFetchOsLogoData* _data_;
	GtkImage* _tmp0_ = NULL;
	GtkImage* _tmp1_ = NULL;
	OsinfoOs* _tmp2_ = NULL;
	OsinfoOs* _tmp3_ = NULL;
	gint _tmp4_ = 0;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderFetchOsLogoData);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_downloader_fetch_os_logo);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_downloader_fetch_os_logo_data_free);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = image;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = _g_object_ref0 (_tmp0_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->image);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->image = _tmp1_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = os;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->os);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->os = _tmp3_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = size;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->size = _tmp4_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_fetch_os_logo_co (_data_);
#line 2619 "downloader.c"
}


void boxes_downloader_fetch_os_logo_finish (GAsyncResult* _res_) {
	BoxesDownloaderFetchOsLogoData* _data_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 2627 "downloader.c"
}


static void _vala_array_add22 (gchar*** array, int* length, int* size, gchar* value) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if ((*length) == (*size)) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		*size = (*size) ? (2 * (*size)) : 4;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		*array = g_renew (gchar*, *array, (*size) + 1);
#line 2638 "downloader.c"
	}
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	(*array)[(*length)++] = value;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	(*array)[*length] = NULL;
#line 2644 "downloader.c"
}


static void boxes_downloader_fetch_os_logo_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderFetchOsLogoData* _data_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_fetch_os_logo_co (_data_);
#line 2658 "downloader.c"
}


static gboolean boxes_downloader_fetch_os_logo_co (BoxesDownloaderFetchOsLogoData* _data_) {
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 0:
#line 2667 "downloader.c"
		goto _state_0;
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 1:
#line 2671 "downloader.c"
		goto _state_1;
		default:
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 2676 "downloader.c"
	}
	_state_0:
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->os;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = NULL;
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = boxes_downloader_fetch_os_logo_url (_data_->_tmp0_);
#line 174 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->logo_url = _data_->_tmp1_;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = NULL;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->logo_url;
#line 175 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp2_ == NULL) {
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->logo_url);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 2701 "downloader.c"
		} else {
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 2705 "downloader.c"
		}
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 176 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2711 "downloader.c"
	}
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = NULL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = _data_->os;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = NULL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = osinfo_product_get_name ((OsinfoProduct*) _data_->_tmp3_);
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = NULL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = _data_->_tmp4_;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = NULL;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->logo_url;
#line 178 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:178: %s has logo '%s'.", _data_->_tmp5_, _data_->_tmp6_);
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = NULL;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = _data_->logo_url;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = NULL;
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = g_file_new_for_uri (_data_->_tmp7_);
#line 180 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->remote_file = _data_->_tmp8_;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->remote_file;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = g_file_get_basename (_data_->_tmp9_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = _data_->_tmp10_;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = boxes_get_system_logo_cache (_data_->_tmp11_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = NULL;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = _data_->_tmp12_;
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->_tmp11_);
#line 181 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->system_cached_path = _data_->_tmp13_;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = _data_->remote_file;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = g_file_get_basename (_data_->_tmp14_);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = _data_->_tmp15_;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = boxes_get_logo_cache (_data_->_tmp16_);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = NULL;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = _data_->_tmp17_;
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->_tmp16_);
#line 182 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_path = _data_->_tmp18_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = NULL;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = _data_->cached_path;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = NULL;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = g_strdup (_data_->_tmp19_);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = NULL;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = g_new0 (gchar*, 1 + 1);
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_[0] = _data_->_tmp20_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths_length1 = 0;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_cached_paths_size_ = 0;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths = _data_->_tmp21_;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths_length1 = 1;
#line 184 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_cached_paths_size_ = _data_->cached_paths_length1;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp22_ = NULL;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp22_ = _data_->system_cached_path;
#line 185 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp22_ != NULL) {
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23_ = NULL;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23__length1 = 0;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23_ = _data_->cached_paths;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp23__length1 = _data_->cached_paths_length1;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp24_ = NULL;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp24_ = _data_->system_cached_path;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp25_ = NULL;
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp25_ = g_strdup (_data_->_tmp24_);
#line 186 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_vala_array_add22 (&_data_->cached_paths, &_data_->cached_paths_length1, &_data_->_cached_paths_size_, _data_->_tmp25_);
#line 2837 "downloader.c"
	}
	{
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp26_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp26_ = boxes_downloader_get_instance ();
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp27_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp27_ = _data_->_tmp26_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp28_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp28_ = _data_->remote_file;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp29_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp29__length1 = 0;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp29_ = _data_->cached_paths;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp29__length1 = _data_->cached_paths_length1;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp30_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp30_ = boxes_activity_progress_new ();
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp31_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp31_ = _data_->_tmp30_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_state_ = 1;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		boxes_downloader_download (_data_->_tmp27_, _data_->_tmp28_, _data_->_tmp29_, _data_->_tmp29__length1, _data_->_tmp31_, NULL, boxes_downloader_fetch_os_logo_ready, _data_);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2874 "downloader.c"
		_state_1:
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp32_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp32_ = boxes_downloader_download_finish (_data_->_tmp27_, _data_->_res_, &_data_->_inner_error_);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp33_ = NULL;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp33_ = _data_->_tmp32_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->_tmp31_);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->_tmp27_);
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->cached_file = _data_->_tmp33_;
#line 189 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 2892 "downloader.c"
			goto __catch128_g_error;
		}
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp34_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp34_ = _data_->cached_file;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp35_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp35_ = g_file_get_path (_data_->_tmp34_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp36_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp36_ = _data_->_tmp35_;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp37_ = 0;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp37_ = _data_->size;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp38_ = 0;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp38_ = _data_->size;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp39_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp39_ = gdk_pixbuf_new_from_file_at_size (_data_->_tmp36_, _data_->_tmp37_, _data_->_tmp38_, &_data_->_inner_error_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp40_ = NULL;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp40_ = _data_->_tmp39_;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->_tmp36_);
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->pixbuf = _data_->_tmp40_;
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 190 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->cached_file);
#line 2931 "downloader.c"
			goto __catch128_g_error;
		}
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp41_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp41_ = _data_->image;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp42_ = NULL;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp42_ = _data_->pixbuf;
#line 191 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		gtk_image_set_from_pixbuf (_data_->_tmp41_, _data_->_tmp42_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->pixbuf);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 2948 "downloader.c"
	}
	goto __finally128;
	__catch128_g_error:
	{
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_error_ = _data_->_inner_error_;
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = NULL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp43_ = NULL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp43_ = _data_->logo_url;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp44_ = NULL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp44_ = _data_->_error_;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp45_ = NULL;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp45_ = _data_->_tmp44_->message;
#line 193 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_warning ("downloader.vala:193: Error loading logo file '%s': %s", _data_->_tmp43_, _data_->_tmp45_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data_->_error_);
#line 2973 "downloader.c"
	}
	__finally128:
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->cached_paths = (_vala_array_free (_data_->cached_paths, _data_->cached_paths_length1, (GDestroyNotify) g_free), NULL);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cached_path);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->system_cached_path);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->remote_file);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->logo_url);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_critical ("file %s: line %d: uncaught error: %s (%s, %d)", __FILE__, __LINE__, _data_->_inner_error_->message, g_quark_to_string (_data_->_inner_error_->domain), _data_->_inner_error_->code);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_clear_error (&_data_->_inner_error_);
#line 188 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 2994 "downloader.c"
	}
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_paths = (_vala_array_free (_data_->cached_paths, _data_->cached_paths_length1, (GDestroyNotify) g_free), NULL);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->system_cached_path);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->remote_file);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->logo_url);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3010 "downloader.c"
	} else {
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3014 "downloader.c"
	}
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 173 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3020 "downloader.c"
}


static void boxes_downloader_fetch_media_data_free (gpointer _data) {
	BoxesDownloaderFetchMediaData* _data_;
	_data_ = _data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->uri);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->result);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderFetchMediaData, _data_);
#line 3037 "downloader.c"
}


void boxes_downloader_fetch_media (const gchar* uri, BoxesActivityProgress* progress, GCancellable* cancellable, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderFetchMediaData* _data_;
	const gchar* _tmp0_ = NULL;
	gchar* _tmp1_ = NULL;
	BoxesActivityProgress* _tmp2_ = NULL;
	BoxesActivityProgress* _tmp3_ = NULL;
	GCancellable* _tmp4_ = NULL;
	GCancellable* _tmp5_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderFetchMediaData);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_simple_async_result_new (NULL, _callback_, _user_data_, boxes_downloader_fetch_media);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_downloader_fetch_media_data_free);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = uri;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = g_strdup (_tmp0_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->uri);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->uri = _tmp1_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = progress;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _g_object_ref0 (_tmp2_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->progress = _tmp3_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = cancellable;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = _g_object_ref0 (_tmp4_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cancellable);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cancellable = _tmp5_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_fetch_media_co (_data_);
#line 3081 "downloader.c"
}


gchar* boxes_downloader_fetch_media_finish (GAsyncResult* _res_, GError** error) {
	gchar* result;
	BoxesDownloaderFetchMediaData* _data_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return NULL;
#line 3092 "downloader.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	result = _data_->result;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->result = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return result;
#line 3102 "downloader.c"
}


static void boxes_downloader_fetch_media_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderFetchMediaData* _data_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_fetch_media_co (_data_);
#line 3116 "downloader.c"
}


static gboolean boxes_downloader_fetch_media_co (BoxesDownloaderFetchMediaData* _data_) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 0:
#line 3125 "downloader.c"
		goto _state_0;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 1:
#line 3129 "downloader.c"
		goto _state_1;
		default:
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 3134 "downloader.c"
	}
	_state_0:
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->uri;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = NULL;
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = g_file_new_for_uri (_data_->_tmp0_);
#line 200 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->file = _data_->_tmp1_;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->file;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = NULL;
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = g_file_get_basename (_data_->_tmp2_);
#line 201 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->basename = _data_->_tmp3_;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = NULL;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->basename;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp6_ != NULL) {
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp7_ = NULL;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp7_ = _data_->basename;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp5_ = g_strcmp0 (_data_->_tmp7_, "") != 0;
#line 3169 "downloader.c"
	} else {
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp5_ = FALSE;
#line 3173 "downloader.c"
	}
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp5_) {
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp8_ = NULL;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp8_ = _data_->basename;
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp4_ = g_strcmp0 (_data_->_tmp8_, "/") != 0;
#line 3183 "downloader.c"
	} else {
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp4_ = FALSE;
#line 3187 "downloader.c"
	}
#line 202 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_val_if_fail (_data_->_tmp4_, NULL);
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = NULL;
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = boxes_downloader_get_instance ();
#line 204 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->downloader = _data_->_tmp9_;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp10_ = g_get_user_special_dir (G_USER_DIRECTORY_DOWNLOAD);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = _data_->basename;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = NULL;
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = g_build_filename (_data_->_tmp10_, _data_->_tmp11_, NULL);
#line 205 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cache = _data_->_tmp12_;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = NULL;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = _data_->progress;
#line 208 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_activity_progress_set_progress (_data_->_tmp13_, (gdouble) 0);
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = NULL;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = _data_->uri;
#line 209 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:209: Downloading media from '%s' to '%s'.", _data_->_tmp14_, _data_->cache);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp15_ = _data_->file;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp16_ = g_strdup (_data_->cache);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_ = g_new0 (gchar*, 1 + 1);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp17_[0] = _data_->_tmp16_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18__length1 = 0;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = _data_->_tmp17_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18__length1 = 1;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp19_ = _data_->progress;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp20_ = _data_->cancellable;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 1;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_download (_data_->downloader, _data_->_tmp15_, _data_->_tmp18_, 1, _data_->_tmp19_, _data_->_tmp20_, boxes_downloader_fetch_media_ready, _data_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3259 "downloader.c"
	_state_1:
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp21_ = boxes_downloader_download_finish (_data_->downloader, _data_->_res_, &_data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp22_ = NULL;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp22_ = _data_->_tmp21_;
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->_tmp22_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp18_ = (_vala_array_free (_data_->_tmp18_, _data_->_tmp18__length1, (GDestroyNotify) g_free), NULL);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->cache);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->downloader);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_free0 (_data_->basename);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->file);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3291 "downloader.c"
		} else {
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3295 "downloader.c"
		}
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 210 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 3301 "downloader.c"
	}
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp23_ = NULL;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp23_ = _data_->progress;
#line 211 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_activity_progress_set_progress (_data_->_tmp23_, (gdouble) 1);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->result = _data_->cache;
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->downloader);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->basename);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->file);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3321 "downloader.c"
	} else {
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3325 "downloader.c"
	}
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 213 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cache);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->downloader);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->basename);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->file);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3343 "downloader.c"
	} else {
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3347 "downloader.c"
	}
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 197 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3353 "downloader.c"
}


static void boxes_downloader_await_download_data_free (gpointer _data) {
	BoxesDownloaderAwaitDownloadData* _data_;
	_data_ = _data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->result);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_slice_free (BoxesDownloaderAwaitDownloadData, _data_);
#line 3370 "downloader.c"
}


static void boxes_downloader_await_download (BoxesDownloader* self, BoxesDownload* download, const gchar* cached_path, BoxesActivityProgress* progress, GAsyncReadyCallback _callback_, gpointer _user_data_) {
	BoxesDownloaderAwaitDownloadData* _data_;
	BoxesDownloader* _tmp0_ = NULL;
	BoxesDownload* _tmp1_ = NULL;
	BoxesDownload* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	gchar* _tmp4_ = NULL;
	BoxesActivityProgress* _tmp5_ = NULL;
	BoxesActivityProgress* _tmp6_ = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_slice_new0 (BoxesDownloaderAwaitDownloadData);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_async_result = g_simple_async_result_new (G_OBJECT (self), _callback_, _user_data_, boxes_downloader_await_download);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_simple_async_result_set_op_res_gpointer (_data_->_async_result, _data_, boxes_downloader_await_download_data_free);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = _g_object_ref0 (self);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->self = _tmp0_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = download;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _boxes_download_ref0 (_tmp1_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->download);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->download = _tmp2_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = cached_path;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = g_strdup (_tmp3_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->cached_path);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->cached_path = _tmp4_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = progress;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->progress);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->progress = _tmp6_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_await_download_co (_data_);
#line 3419 "downloader.c"
}


static GFile* boxes_downloader_await_download_finish (BoxesDownloader* self, GAsyncResult* _res_, GError** error) {
	GFile* result;
	BoxesDownloaderAwaitDownloadData* _data_;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_simple_async_result_propagate_error (G_SIMPLE_ASYNC_RESULT (_res_), error)) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return NULL;
#line 3430 "downloader.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = g_simple_async_result_get_op_res_gpointer (G_SIMPLE_ASYNC_RESULT (_res_));
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	result = _data_->result;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->result = NULL;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return result;
#line 3440 "downloader.c"
}


static Block91Data* block91_data_ref (Block91Data* _data91_) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_atomic_int_inc (&_data91_->_ref_count_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return _data91_;
#line 3449 "downloader.c"
}


static void block91_data_unref (void * _userdata_) {
	Block91Data* _data91_;
	_data91_ = (Block91Data*) _userdata_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_atomic_int_dec_and_test (&_data91_->_ref_count_)) {
#line 3458 "downloader.c"
		BoxesDownloader* self;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		self = _data91_->self;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		(_data91_->callback_target_destroy_notify == NULL) ? NULL : (_data91_->callback_target_destroy_notify (_data91_->callback_target), NULL);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data91_->callback = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data91_->callback_target = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data91_->callback_target_destroy_notify = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_error_free0 (_data91_->download_error);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data91_->downloaded_file);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_boxes_download_unref0 (_data91_->download);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (self);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_slice_free (Block91Data, _data91_);
#line 3480 "downloader.c"
	}
}


static gboolean _boxes_downloader_await_download_co_gsource_func (gpointer self) {
	gboolean result;
	result = boxes_downloader_await_download_co (self);
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return result;
#line 3490 "downloader.c"
}


static void __lambda41_ (Block91Data* _data91_, BoxesDownloader* downloader, BoxesDownload* downloaded) {
	BoxesDownloader* self;
	BoxesDownload* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesDownload* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	BoxesDownload* _tmp4_ = NULL;
	GFile* _tmp5_ = NULL;
	GFile* _tmp6_ = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = _data91_->self;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (downloader != NULL);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (downloaded != NULL);
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = downloaded;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = _tmp0_->uri;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _data91_->download;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _tmp2_->uri;
#line 225 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_strcmp0 (_tmp1_, _tmp3_) != 0) {
#line 226 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return;
#line 3521 "downloader.c"
	}
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = downloaded;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = _tmp4_->cached_file;
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp6_ = _g_object_ref0 (_tmp5_);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data91_->downloaded_file);
#line 228 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data91_->downloaded_file = _tmp6_;
#line 229 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data91_->callback (_data91_->callback_target);
#line 3535 "downloader.c"
}


static void ___lambda41__boxes_downloader_downloaded (BoxesDownloader* _sender, BoxesDownload* download, gpointer self) {
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	__lambda41_ (self, _sender, download);
#line 3542 "downloader.c"
}


static void __lambda42_ (Block91Data* _data91_, BoxesDownloader* downloader, BoxesDownload* failed_download, GError* _error_) {
	BoxesDownloader* self;
	BoxesDownload* _tmp0_ = NULL;
	const gchar* _tmp1_ = NULL;
	BoxesDownload* _tmp2_ = NULL;
	const gchar* _tmp3_ = NULL;
	GError* _tmp4_ = NULL;
	GError* _tmp5_ = NULL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = _data91_->self;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (downloader != NULL);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (failed_download != NULL);
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp0_ = failed_download;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp1_ = _tmp0_->uri;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp2_ = _data91_->download;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp3_ = _tmp2_->uri;
#line 232 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (g_strcmp0 (_tmp1_, _tmp3_) != 0) {
#line 233 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return;
#line 3572 "downloader.c"
	}
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp4_ = _error_;
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_tmp5_ = _g_error_copy0 (_tmp4_);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_error_free0 (_data91_->download_error);
#line 235 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data91_->download_error = _tmp5_;
#line 236 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data91_->callback (_data91_->callback_target);
#line 3584 "downloader.c"
}


static void ___lambda42__boxes_downloader_download_failed (BoxesDownloader* _sender, BoxesDownload* download, GError* _error_, gpointer self) {
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	__lambda42_ (self, _sender, download, _error_);
#line 3591 "downloader.c"
}


static void boxes_downloader_await_download_ready (GObject* source_object, GAsyncResult* _res_, gpointer _user_data_) {
	BoxesDownloaderAwaitDownloadData* _data_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_ = _user_data_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_source_object_ = source_object;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_res_ = _res_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_await_download_co (_data_);
#line 3605 "downloader.c"
}


static gboolean boxes_downloader_await_download_co (BoxesDownloaderAwaitDownloadData* _data_) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	switch (_data_->_state_) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 0:
#line 3614 "downloader.c"
		goto _state_0;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 1:
#line 3618 "downloader.c"
		goto _state_1;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		case 2:
#line 3622 "downloader.c"
		goto _state_2;
		default:
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_assert_not_reached ();
#line 3627 "downloader.c"
	}
	_state_0:
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_ = g_slice_new0 (Block91Data);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_->_ref_count_ = 1;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_->self = g_object_ref (_data_->self);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp0_ = _data_->download;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_boxes_download_unref0 (_data_->_data91_->download);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_->download = _data_->_tmp0_;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_->_async_data_ = _data_;
#line 219 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_->downloaded_file = NULL;
#line 220 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_->download_error = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp1_ = _data_->_data91_->download;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp2_ = _data_->_tmp1_->progress;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = NULL;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp3_ = _data_->progress;
#line 222 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_bind_property_with_closures ((GObject*) _data_->_tmp2_, "progress", (GObject*) _data_->_tmp3_, "progress", G_BINDING_SYNC_CREATE, (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)), (GClosure*) ((NULL == NULL) ? NULL : g_cclosure_new ((GCallback) NULL, NULL, NULL)));
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_->callback = _boxes_downloader_await_download_co_gsource_func;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_->callback_target = _data_;
#line 223 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_->callback_target_destroy_notify = NULL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = 0UL;
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp4_ = g_signal_connect_data (_data_->self, "downloaded", (GCallback) ___lambda41__boxes_downloader_downloaded, block91_data_ref (_data_->_data91_), (GClosureNotify) block91_data_unref, 0);
#line 224 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->downloaded_id = _data_->_tmp4_;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = 0UL;
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp5_ = g_signal_connect_data (_data_->self, "download-failed", (GCallback) ___lambda42__boxes_downloader_download_failed, block91_data_ref (_data_->_data91_), (GClosureNotify) block91_data_unref, 0);
#line 231 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->downloaded_failed_id = _data_->_tmp5_;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = NULL;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp6_ = _data_->_data91_->download;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = NULL;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp7_ = _data_->_tmp6_->uri;
#line 239 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:239: '%s' already being downloaded. Waiting for downlo" \
"ad to complete..", _data_->_tmp7_);
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_state_ = 1;
#line 240 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3696 "downloader.c"
	_state_1:
	;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = NULL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp8_ = _data_->_data91_->download;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = NULL;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp9_ = _data_->_tmp8_->uri;
#line 241 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_debug ("downloader.vala:241: Finished waiting for '%s' to download.", _data_->_tmp9_);
#line 242 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_handler_disconnect ((GObject*) _data_->self, _data_->downloaded_id);
#line 243 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_handler_disconnect ((GObject*) _data_->self, _data_->downloaded_failed_id);
#line 245 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_data91_->download_error != NULL) {
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = NULL;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp10_ = _g_error_copy0 (_data_->_data91_->download_error);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_inner_error_ = _data_->_tmp10_;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_error_free (_data_->_inner_error_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		block91_data_unref (_data_->_data91_);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_data91_ = NULL;
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (_data_->_state_ == 0) {
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3733 "downloader.c"
		} else {
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_complete (_data_->_async_result);
#line 3737 "downloader.c"
		}
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_object_unref (_data_->_async_result);
#line 246 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 3743 "downloader.c"
	}
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = NULL;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp11_ = g_file_get_path (_data_->_data91_->downloaded_file);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = NULL;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp12_ = _data_->_tmp11_;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = NULL;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp13_ = _data_->cached_path;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = FALSE;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_tmp14_ = g_strcmp0 (_data_->_tmp12_, _data_->_tmp13_) != 0;
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_free0 (_data_->_tmp12_);
#line 249 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_tmp14_) {
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp15_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp15_ = _data_->cached_path;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp16_ = NULL;
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp16_ = g_file_new_for_path (_data_->_tmp15_);
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 250 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->cached_file = _data_->_tmp16_;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp17_ = NULL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp17_ = _data_->cached_file;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_state_ = 2;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_file_copy_async (_data_->_data91_->downloaded_file, _data_->_tmp17_, G_FILE_COPY_OVERWRITE, G_PRIORITY_DEFAULT, NULL, NULL, NULL, boxes_downloader_await_download_ready, _data_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		return FALSE;
#line 3787 "downloader.c"
		_state_2:
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_file_copy_finish (_data_->_data91_->downloaded_file, _data_->_res_, &_data_->_inner_error_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		if (G_UNLIKELY (_data_->_inner_error_ != NULL)) {
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_simple_async_result_set_from_error (_data_->_async_result, _data_->_inner_error_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_error_free (_data_->_inner_error_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_g_object_unref0 (_data_->cached_file);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			block91_data_unref (_data_->_data91_);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			_data_->_data91_ = NULL;
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			if (_data_->_state_ == 0) {
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3807 "downloader.c"
			} else {
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
				g_simple_async_result_complete (_data_->_async_result);
#line 3811 "downloader.c"
			}
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			g_object_unref (_data_->_async_result);
#line 251 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
			return FALSE;
#line 3817 "downloader.c"
		}
	} else {
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp18_ = NULL;
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->_tmp18_ = _g_object_ref0 (_data_->_data91_->downloaded_file);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_g_object_unref0 (_data_->cached_file);
#line 253 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		_data_->cached_file = _data_->_tmp18_;
#line 3828 "downloader.c"
	}
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->result = _data_->cached_file;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	block91_data_unref (_data_->_data91_);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_ = NULL;
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3840 "downloader.c"
	} else {
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3844 "downloader.c"
	}
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 255 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (_data_->cached_file);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	block91_data_unref (_data_->_data91_);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_data_->_data91_ = NULL;
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (_data_->_state_ == 0) {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete_in_idle (_data_->_async_result);
#line 3860 "downloader.c"
	} else {
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		g_simple_async_result_complete (_data_->_async_result);
#line 3864 "downloader.c"
	}
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_object_unref (_data_->_async_result);
#line 216 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	return FALSE;
#line 3870 "downloader.c"
}


static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__BOXES_DOWNLOAD) (gpointer data1, gpointer arg_1, gpointer data2);
	register GMarshalFunc_VOID__BOXES_DOWNLOAD callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (n_param_values == 2);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data1 = closure->data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data2 = param_values->data[0].v_pointer;
#line 3889 "downloader.c"
	} else {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data1 = param_values->data[0].v_pointer;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data2 = closure->data;
#line 3895 "downloader.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	callback = (GMarshalFunc_VOID__BOXES_DOWNLOAD) (marshal_data ? marshal_data : cc->callback);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	callback (data1, boxes_value_get_download (param_values + 1), data2);
#line 3901 "downloader.c"
}


static void g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD_POINTER (GClosure * closure, GValue * return_value, guint n_param_values, const GValue * param_values, gpointer invocation_hint, gpointer marshal_data) {
	typedef void (*GMarshalFunc_VOID__BOXES_DOWNLOAD_POINTER) (gpointer data1, gpointer arg_1, gpointer arg_2, gpointer data2);
	register GMarshalFunc_VOID__BOXES_DOWNLOAD_POINTER callback;
	register GCClosure * cc;
	register gpointer data1;
	register gpointer data2;
	cc = (GCClosure *) closure;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_return_if_fail (n_param_values == 3);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	if (G_CCLOSURE_SWAP_DATA (closure)) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data1 = closure->data;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data2 = param_values->data[0].v_pointer;
#line 3920 "downloader.c"
	} else {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data1 = param_values->data[0].v_pointer;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
		data2 = closure->data;
#line 3926 "downloader.c"
	}
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	callback = (GMarshalFunc_VOID__BOXES_DOWNLOAD_POINTER) (marshal_data ? marshal_data : cc->callback);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	callback (data1, boxes_value_get_download (param_values + 1), g_value_get_pointer (param_values + 2), data2);
#line 3932 "downloader.c"
}


static void boxes_downloader_class_init (BoxesDownloaderClass * klass) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	boxes_downloader_parent_class = g_type_class_peek_parent (klass);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_type_class_add_private (klass, sizeof (BoxesDownloaderPrivate));
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	G_OBJECT_CLASS (klass)->finalize = boxes_downloader_finalize;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_new ("downloaded", BOXES_TYPE_DOWNLOADER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD, G_TYPE_NONE, 1, BOXES_TYPE_DOWNLOAD);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	g_signal_new ("download_failed", BOXES_TYPE_DOWNLOADER, G_SIGNAL_RUN_LAST, 0, NULL, NULL, g_cclosure_user_marshal_VOID__BOXES_DOWNLOAD_POINTER, G_TYPE_NONE, 2, BOXES_TYPE_DOWNLOAD, G_TYPE_POINTER);
#line 3947 "downloader.c"
}


static void boxes_downloader_instance_init (BoxesDownloader * self) {
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self->priv = BOXES_DOWNLOADER_GET_PRIVATE (self);
#line 3954 "downloader.c"
}


static void boxes_downloader_finalize (GObject* obj) {
	BoxesDownloader * self;
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	self = G_TYPE_CHECK_INSTANCE_CAST (obj, BOXES_TYPE_DOWNLOADER, BoxesDownloader);
#line 17 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_object_unref0 (self->priv->session);
#line 19 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	_g_hash_table_unref0 (self->priv->downloads);
#line 15 "/home/zeenix/checkout/gnome/gnome-boxes/src/downloader.vala"
	G_OBJECT_CLASS (boxes_downloader_parent_class)->finalize (obj);
#line 3968 "downloader.c"
}


GType boxes_downloader_get_type (void) {
	static volatile gsize boxes_downloader_type_id__volatile = 0;
	if (g_once_init_enter (&boxes_downloader_type_id__volatile)) {
		static const GTypeInfo g_define_type_info = { sizeof (BoxesDownloaderClass), (GBaseInitFunc) NULL, (GBaseFinalizeFunc) NULL, (GClassInitFunc) boxes_downloader_class_init, (GClassFinalizeFunc) NULL, NULL, sizeof (BoxesDownloader), 0, (GInstanceInitFunc) boxes_downloader_instance_init, NULL };
		GType boxes_downloader_type_id;
		boxes_downloader_type_id = g_type_register_static (G_TYPE_OBJECT, "BoxesDownloader", &g_define_type_info, 0);
		g_once_init_leave (&boxes_downloader_type_id__volatile, boxes_downloader_type_id);
	}
	return boxes_downloader_type_id__volatile;
}


static void _vala_array_destroy (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	if ((array != NULL) && (destroy_func != NULL)) {
#line 3987 "downloader.c"
		int i;
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
		for (i = 0; i < array_length; i = i + 1) {
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
			if (((gpointer*) array)[i] != NULL) {
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
				destroy_func (((gpointer*) array)[i]);
#line 3995 "downloader.c"
			}
		}
	}
}


static void _vala_array_free (gpointer array, gint array_length, GDestroyNotify destroy_func) {
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	_vala_array_destroy (array, array_length, destroy_func);
#line 476 "/home/zeenix/checkout/gnome/gnome-boxes/src/libvirt-machine.vala"
	g_free (array);
#line 4007 "downloader.c"
}



